==> ejc-riskmortgage-api-3.0.0-20220711.084654-51-sources.jar: com/ejianc/business/payer/vo/PayerChangeVO.java <==
package com.ejianc.business.payer.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 缴纳员工明细变更表主实体
 * 
 * @author generator
 * 
 */
public class PayerChangeVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编号
    private Integer billState; // 单据状态
    private Long standardId; // 申请标准表Id
    private String standardCode; // 申请标准表code
    private String standardName; // 申请标准表名称
    private Long orgId; // 申请组织Id
    private String orgName; // 申请组织名称
    private String orgCode; // 申请组织编码
    @JsonFormat(pattern = "yyyy", timezone = "GMT+8")
    private Date belongYear; // 所属年度
    private BigDecimal riskDepositMny; // 风险金缴纳金额
    private BigDecimal totalPayerMny; // 员工应缴纳金额
    private Long employeeId; // 经办人id（申请人）
    private String employeeName; // 经办人名称（申请人）
    private Long departmentId; // 经办人部门id
    private String departmentName; // 经办人部门
    private String memo; // 备注
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date effectDate; // 生效日期
    private String changeCode; // 变更单号
    private Integer changeVersion; // 变更版本
    private Long changeId; // 变更主键
    private Integer changeStatus; // 变更状态(1-未变更 2-变更中 3-已变更)
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date changeDate; // 变更日期
    private BigDecimal beforeChangePayerMny; // 变更前缴纳金额
    private BigDecimal changingPayerMny; // 变更中缴纳金额
    private Long directPayerId; // 直管部缴纳员工明细id（用于数据引用）
    private Long projectId; // 项目Id
    private String projectName; // 项目名称
    private String projectCode; // 项目编码
    private String riskDepositType; // 风险保证金类型(directDept-直管部、projectDept-项目部)
    private String changeItems; // 变更项：用、号隔开。如：数量、单价、税率、甲方、乙方；
    private Long changeEmployeeId; // 变更经办人id
    private String changeEmployeeName; // 变更经办人名称
    private BigDecimal changePayerMny; // 本次变更金额
    private BigDecimal changeScale; // 本次变更比例
    private String changeReason; // 变更原因描述
    private Long mainPayerId; // 缴纳员工明细主表id
    private String mainPayerCode; // 缴纳员工明细主表单据编码
    private BigDecimal baseMny; //初始版本金额
    
    private List<PayerChangeDetailVO> detailList = new ArrayList<>(); // 缴纳员工明细变更表子实体

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getStandardId() {
        return standardId;
    }

    @ReferDeserialTransfer
    public void setStandardId(Long standardId) {
        this.standardId = standardId;
    }
    public String getStandardCode() {
        return standardCode;
    }

    public void setStandardCode(String standardCode) {
        this.standardCode = standardCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public Date getBelongYear() {
        return belongYear;
    }

    public void setBelongYear(Date belongYear) {
        this.belongYear = belongYear;
    }
    public BigDecimal getRiskDepositMny() {
        return riskDepositMny;
    }

    public void setRiskDepositMny(BigDecimal riskDepositMny) {
        this.riskDepositMny = riskDepositMny;
    }
    public BigDecimal getTotalPayerMny() {
        return totalPayerMny;
    }

    public void setTotalPayerMny(BigDecimal totalPayerMny) {
        this.totalPayerMny = totalPayerMny;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    @ReferDeserialTransfer
    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Date getEffectDate() {
        return effectDate;
    }

    public void setEffectDate(Date effectDate) {
        this.effectDate = effectDate;
    }
    public String getChangeCode() {
        return changeCode;
    }

    public void setChangeCode(String changeCode) {
        this.changeCode = changeCode;
    }
    public Integer getChangeVersion() {
        return changeVersion;
    }

    public void setChangeVersion(Integer changeVersion) {
        this.changeVersion = changeVersion;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public Integer getChangeStatus() {
        return changeStatus;
    }

    public void setChangeStatus(Integer changeStatus) {
        this.changeStatus = changeStatus;
    }
    public Date getChangeDate() {
        return changeDate;
    }

    public void setChangeDate(Date changeDate) {
        this.changeDate = changeDate;
    }
    public BigDecimal getBeforeChangePayerMny() {
        return beforeChangePayerMny;
    }

    public void setBeforeChangePayerMny(BigDecimal beforeChangePayerMny) {
        this.beforeChangePayerMny = beforeChangePayerMny;
    }
    public BigDecimal getChangingPayerMny() {
        return changingPayerMny;
    }

    public void setChangingPayerMny(BigDecimal changingPayerMny) {
        this.changingPayerMny = changingPayerMny;
    }
    public Long getDirectPayerId() {
        return directPayerId;
    }

    public void setDirectPayerId(Long directPayerId) {
        this.directPayerId = directPayerId;
    }
    public Long getProjectId() {
        return projectId;
    }

    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getRiskDepositType() {
        return riskDepositType;
    }

    public void setRiskDepositType(String riskDepositType) {
        this.riskDepositType = riskDepositType;
    }
    public String getChangeItems() {
        return changeItems;
    }

    public void setChangeItems(String changeItems) {
        this.changeItems = changeItems;
    }
    public Long getChangeEmployeeId() {
        return changeEmployeeId;
    }
    @ReferDeserialTransfer
    public void setChangeEmployeeId(Long changeEmployeeId) {
        this.changeEmployeeId = changeEmployeeId;
    }
    public String getChangeEmployeeName() {
        return changeEmployeeName;
    }

    public void setChangeEmployeeName(String changeEmployeeName) {
        this.changeEmployeeName = changeEmployeeName;
    }
    public BigDecimal getChangePayerMny() {
        return changePayerMny;
    }

    public void setChangePayerMny(BigDecimal changePayerMny) {
        this.changePayerMny = changePayerMny;
    }
    public BigDecimal getChangeScale() {
        return changeScale;
    }

    public void setChangeScale(BigDecimal changeScale) {
        this.changeScale = changeScale;
    }
    public String getChangeReason() {
        return changeReason;
    }

    public void setChangeReason(String changeReason) {
        this.changeReason = changeReason;
    }
    public Long getMainPayerId() {
        return mainPayerId;
    }

    public void setMainPayerId(Long mainPayerId) {
        this.mainPayerId = mainPayerId;
    }
    public String getMainPayerCode() {
        return mainPayerCode;
    }

    public void setMainPayerCode(String mainPayerCode) {
        this.mainPayerCode = mainPayerCode;
    }

    public List<PayerChangeDetailVO> getDetailList() {
        return detailList;
    }

    public void setDetailList(List<PayerChangeDetailVO> detailList) {
        this.detailList = detailList;
    }

    public BigDecimal getBaseMny() {
        return baseMny;
    }

    public void setBaseMny(BigDecimal baseMny) {
        this.baseMny = baseMny;
    }

    public String getStandardName() {
        return standardName;
    }

    public void setStandardName(String standardName) {
        this.standardName = standardName;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
}

==> ejc-riskmortgage-api-3.0.0-20220711.120552-53-sources.jar: com/ejianc/business/payer/vo/PayerChangeVO.java <==
package com.ejianc.business.payer.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 缴纳员工明细变更表主实体
 * 
 * @author generator
 * 
 */
public class PayerChangeVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编号
    private Integer billState; // 单据状态
    private Long standardId; // 申请标准表Id
    private String standardCode; // 申请标准表code
    private String standardName; // 申请标准表名称
    private Long orgId; // 申请组织Id
    private String orgName; // 申请组织名称
    private String orgCode; // 申请组织编码
    @JsonFormat(pattern = "yyyy", timezone = "GMT+8")
    private Date belongYear; // 所属年度
    private BigDecimal riskDepositMny; // 风险金缴纳金额
    private BigDecimal totalPayerMny; // 员工应缴纳金额
    private Long employeeId; // 经办人id（申请人）
    private String employeeName; // 经办人名称（申请人）
    private Long departmentId; // 经办人部门id
    private String departmentName; // 经办人部门
    private String memo; // 备注
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date effectDate; // 生效日期
    private String changeCode; // 变更单号
    private Integer changeVersion; // 变更版本
    private Long changeId; // 变更主键
    private Integer changeStatus; // 变更状态(1-未变更 2-变更中 3-已变更)
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date changeDate; // 变更日期
    private BigDecimal beforeChangePayerMny; // 变更前缴纳金额
    private BigDecimal changingPayerMny; // 变更中缴纳金额
    private Long directPayerId; // 直管部缴纳员工明细id（用于数据引用）
    private Long projectId; // 项目Id
    private String projectName; // 项目名称
    private String projectCode; // 项目编码
    private String riskDepositType; // 风险保证金类型(directDept-直管部、projectDept-项目部)
    private String changeItems; // 变更项：用、号隔开。如：数量、单价、税率、甲方、乙方；
    private Long changeEmployeeId; // 变更经办人id
    private String changeEmployeeName; // 变更经办人名称
    private BigDecimal changePayerMny; // 本次变更金额
    private BigDecimal changeScale; // 本次变更比例
    private String changeReason; // 变更原因描述
    private Long mainPayerId; // 缴纳员工明细主表id
    private String mainPayerCode; // 缴纳员工明细主表单据编码
    private BigDecimal baseMny; //初始版本金额

    private BigDecimal riskDepositMnyWan; // 风险金缴纳金额（万元）（转成万元）
    private BigDecimal totalPayerMnyWan; // 员工应缴纳金额（万元）（转成万元）
    private BigDecimal changePayerMnyWan; // 本次变更金额（万元）（转成万元）


    private List<PayerChangeDetailVO> detailList = new ArrayList<>(); // 缴纳员工明细变更表子实体

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getStandardId() {
        return standardId;
    }

    @ReferDeserialTransfer
    public void setStandardId(Long standardId) {
        this.standardId = standardId;
    }
    public String getStandardCode() {
        return standardCode;
    }

    public void setStandardCode(String standardCode) {
        this.standardCode = standardCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public Date getBelongYear() {
        return belongYear;
    }

    public void setBelongYear(Date belongYear) {
        this.belongYear = belongYear;
    }
    public BigDecimal getRiskDepositMny() {
        return riskDepositMny;
    }

    public void setRiskDepositMny(BigDecimal riskDepositMny) {
        this.riskDepositMny = riskDepositMny;
    }
    public BigDecimal getTotalPayerMny() {
        return totalPayerMny;
    }

    public void setTotalPayerMny(BigDecimal totalPayerMny) {
        this.totalPayerMny = totalPayerMny;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    @ReferDeserialTransfer
    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Date getEffectDate() {
        return effectDate;
    }

    public void setEffectDate(Date effectDate) {
        this.effectDate = effectDate;
    }
    public String getChangeCode() {
        return changeCode;
    }

    public void setChangeCode(String changeCode) {
        this.changeCode = changeCode;
    }
    public Integer getChangeVersion() {
        return changeVersion;
    }

    public void setChangeVersion(Integer changeVersion) {
        this.changeVersion = changeVersion;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public Integer getChangeStatus() {
        return changeStatus;
    }

    public void setChangeStatus(Integer changeStatus) {
        this.changeStatus = changeStatus;
    }
    public Date getChangeDate() {
        return changeDate;
    }

    public void setChangeDate(Date changeDate) {
        this.changeDate = changeDate;
    }
    public BigDecimal getBeforeChangePayerMny() {
        return beforeChangePayerMny;
    }

    public void setBeforeChangePayerMny(BigDecimal beforeChangePayerMny) {
        this.beforeChangePayerMny = beforeChangePayerMny;
    }
    public BigDecimal getChangingPayerMny() {
        return changingPayerMny;
    }

    public void setChangingPayerMny(BigDecimal changingPayerMny) {
        this.changingPayerMny = changingPayerMny;
    }
    public Long getDirectPayerId() {
        return directPayerId;
    }

    public void setDirectPayerId(Long directPayerId) {
        this.directPayerId = directPayerId;
    }
    public Long getProjectId() {
        return projectId;
    }

    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getRiskDepositType() {
        return riskDepositType;
    }

    public void setRiskDepositType(String riskDepositType) {
        this.riskDepositType = riskDepositType;
    }
    public String getChangeItems() {
        return changeItems;
    }

    public void setChangeItems(String changeItems) {
        this.changeItems = changeItems;
    }
    public Long getChangeEmployeeId() {
        return changeEmployeeId;
    }
    @ReferDeserialTransfer
    public void setChangeEmployeeId(Long changeEmployeeId) {
        this.changeEmployeeId = changeEmployeeId;
    }
    public String getChangeEmployeeName() {
        return changeEmployeeName;
    }

    public void setChangeEmployeeName(String changeEmployeeName) {
        this.changeEmployeeName = changeEmployeeName;
    }
    public BigDecimal getChangePayerMny() {
        return changePayerMny;
    }

    public void setChangePayerMny(BigDecimal changePayerMny) {
        this.changePayerMny = changePayerMny;
    }
    public BigDecimal getChangeScale() {
        return changeScale;
    }

    public void setChangeScale(BigDecimal changeScale) {
        this.changeScale = changeScale;
    }
    public String getChangeReason() {
        return changeReason;
    }

    public void setChangeReason(String changeReason) {
        this.changeReason = changeReason;
    }
    public Long getMainPayerId() {
        return mainPayerId;
    }

    public void setMainPayerId(Long mainPayerId) {
        this.mainPayerId = mainPayerId;
    }
    public String getMainPayerCode() {
        return mainPayerCode;
    }

    public void setMainPayerCode(String mainPayerCode) {
        this.mainPayerCode = mainPayerCode;
    }

    public List<PayerChangeDetailVO> getDetailList() {
        return detailList;
    }

    public void setDetailList(List<PayerChangeDetailVO> detailList) {
        this.detailList = detailList;
    }

    public BigDecimal getBaseMny() {
        return baseMny;
    }

    public void setBaseMny(BigDecimal baseMny) {
        this.baseMny = baseMny;
    }

    public String getStandardName() {
        return standardName;
    }

    public void setStandardName(String standardName) {
        this.standardName = standardName;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public BigDecimal getRiskDepositMnyWan() {
        return riskDepositMnyWan;
    }

    public void setRiskDepositMnyWan(BigDecimal riskDepositMnyWan) {
        this.riskDepositMnyWan = riskDepositMnyWan;
    }

    public BigDecimal getTotalPayerMnyWan() {
        return totalPayerMnyWan;
    }

    public void setTotalPayerMnyWan(BigDecimal totalPayerMnyWan) {
        this.totalPayerMnyWan = totalPayerMnyWan;
    }

    public BigDecimal getChangePayerMnyWan() {
        return changePayerMnyWan;
    }

    public void setChangePayerMnyWan(BigDecimal changePayerMnyWan) {
        this.changePayerMnyWan = changePayerMnyWan;
    }
}
